Formula

Struct Formula 

pub struct Formula(pub Vec<Clause>);
A formula; it’s a list of conjoined clauses

Tuple Fields

0: Vec<Clause>

Implementations

Source

impl Formula

pub fn empty() -> Formula

An empty formula

pub fn new(clauses: Vec<Clause>) -> Formula

A new formula with the given vector of clauses

pub fn add(&mut self, clause: Clause)

Add a clause to the current formula

pub fn filter_clauses(&self, model: &Model) -> Formula

Return a formula only containing true literals in each clause

pub fn find_implicant(&self, model: &Model) -> HashSet<i32>

Obtain an implicant of the formula based on the model

pub fn iter(&self) -> impl Iterator<Item = &Clause>

pub fn concat(&self, clause: &Clause) -> Self

pub fn concat_mut(&mut self, clause: &Clause) -> &mut Self

pub fn distribute(&self, formula: &Formula) -> Self

pub fn distribute_mut(&mut self, formula: &Formula) -> &mut Self