pub struct Model(pub Vec<bool>);Expand description
A model as a vector mapping literals to boolea values
Note that the indices are off by one as SAT variables start at 1.
Tuple Fields
0: Vec<bool>Implementations