pub trait AddConstraints<C> {
// Required method
fn insert(&mut self, constraints: &C);
}Expand description
This trait captures the ability to add constraints to a SAT solver.
pub trait AddConstraints<C> {
// Required method
fn insert(&mut self, constraints: &C);
}This trait captures the ability to add constraints to a SAT solver.